@@ -540,15 +540,14 @@ class FastACELoss3DV2(nn.Module):
 
 
 
-
-class FastACELoss3DV3(nn.Module):
+class FACELoss(nn.Module):
     """
     Active contour based elastic model loss
     based on minpooling & maxpooling and laplace filter
     """
 
-    def __init__(self, miu=1.0, alpha=1e-3, beta=2.0, classes=4, types="other", smooth = 1e+3):
-        super(FastACELoss3DV3, self).__init__()
+    def __init__(self, miu=1, alpha=1e-3, beta=2.0, classes=4, types="else"):
+        super(FACELoss, self).__init__()
         self.miu = miu
         self.alpha = alpha
         self.beta = beta
@@ -556,7 +555,6 @@ class FastACELoss3DV3(nn.Module):
         self.types = types
         laplace_kernel = np.ones((3, 3, 3))
         laplace_kernel[1, 1, 1] = -26
-        self.smooth = smooth
 
         self.laplace = nn.Parameter(
             torch.from_numpy(laplace_kernel).float().unsqueeze(
@@ -579,7 +577,7 @@ class FastACELoss3DV3(nn.Module):
         length = torch.abs(contour)
 
         # curvature
-        if self.types:
+        if self.types == 'other':
             curvature = torch.abs(diff)
             curvature = (curvature - curvature.min()) / \
                 (curvature.max() - curvature.min() + 1e-8)
@@ -594,11 +592,13 @@ class FastACELoss3DV3(nn.Module):
         label = label.float()
         c_in = torch.ones_like(predication)
         c_out = torch.zeros_like(predication)
-        region_in = torch.abs(torch.sum(predication * ((label - c_in) ** 2))) / self.smooth
+        region_in = torch.abs(torch.mean(predication * ((label - c_in) ** 2)))
         region_out = torch.abs(
-            torch.sum((1 - predication) * ((label - c_out) ** 2))) / self.smooth
+            torch.mean((1 - predication) * ((label - c_out) ** 2)))
         region = self.miu * region_in + region_out
 
         # elastic
-        elastic = torch.sum((self.alpha + self.beta * curvature ** 2) * length) / self.smooth
-        return region + elastic
\ No newline at end of file
+        elastic = torch.mean((self.alpha + self.beta * curvature ** 2) * length)
+        return region + elastic
+
+
