@@ -232,7 +232,7 @@ class Deep_Supervision_UNet3d(nn.Module):
 
         conv_kwargs1 = {'kernel_size' : 3, 'padding' : 1,  'stride' : 1}
         conv_kwargs2 = {'kernel_size' : 3, 'stride' : 1, 'padding':1}
-        transp_kwargs = {'kernel_size' : 3, 'padding' : 1, 'stride' : 2}
+        transp_kwargs = {'kernel_size' : 2, 'stride' : 1, 'stride' : 2}
 
 
         self.decoder1_trans = ConvDropoutNormNonlin(320, 256, conv_kwargs= transp_kwargs, conv_op = nn.ConvTranspose3d)
@@ -282,10 +282,10 @@ class Deep_Supervision_UNet3d(nn.Module):
         x4 = self.encoder4(x3)
         x5 = self.encoder5(x4)
 
-        x4_ = self.decoder1_conv(torch.cat((x4, self.decoder1_trans(x5, output_size = (x4.shape[-3], x4.shape[-2], x4.shape[-1]))), dim = 1))
-        x3_ = self.decoder2_conv(torch.cat((x3, self.decoder2_trans(x4_, output_size = (x3.shape[-3], x3.shape[-2], x3.shape[-1]))), dim = 1))
-        x2_ = self.decoder3_conv(torch.cat((x2, self.decoder3_trans(x3_, output_size = (x2.shape[-3], x2.shape[-2], x2.shape[-1]))), dim = 1))
-        x1_ = self.decoder4_conv(torch.cat((x1, self.decoder4_trans(x2_, output_size = (x1.shape[-3], x1.shape[-2], x1.shape[-1]))), dim = 1))
+        x4_ = self.decoder1_conv(torch.cat((x4, self.decoder1_trans(x5)), dim = 1))
+        x3_ = self.decoder2_conv(torch.cat((x3, self.decoder2_trans(x4_)), dim = 1))
+        x2_ = self.decoder3_conv(torch.cat((x2, self.decoder3_trans(x3_)), dim = 1))
+        x1_ = self.decoder4_conv(torch.cat((x1, self.decoder4_trans(x2_)), dim = 1))
 
         if not self.is_binary:
             x1_ = F.softmax(self.final_layer1(x1_).view(bs, self.final_output_channels, -1), dim = 1).view(bs, self.final_output_channels, nx, ny, nz)
@@ -441,10 +441,6 @@ class Interactive_Model(nn.Module):
 
 
 
-
-
-
-
 def conv3x3x3(in_planes, out_planes, stride=1, dilation=1):
     # 3x3x3 convolution with padding
     return nn.Conv3d(
